<#if isPolled == true>
/**
 * UART Control Commands - Polled Example Driver File
 * 
 <#if isTestMode == true>
 * @file uc3.c
 *
 * @addtogroup uart-control-commands-example UART Control Commands
 <#else>
 * @file uart_example.c
 * 
 * @addtogroup uart-example
  </#if>
 * 
 * @brief This is the generated example implementation for the UART Control Commands - Polled driver.
 *
 * @version UART Control Commands - Polled Example Version 1.0.0
*/
<#elseif isCallback == true>
/**
 * UART Control Commands - Callback Example Driver File
 * 
 <#if isTestMode == true>
 * @file uc3.c
 <#else>
 * @file uart_example.c
 </#if>
 * 
 * @addtogroup uart-example
 * 
 * @brief This is the generated example implementation for the UART Control Commands - Callback driver.
 *
 * @version UART Control Commands - Callback Example Version 1.0.0
*/
</#if>
${disclaimer}

<#if isPolled == true>
/* Use Case 3 - Polled implementation. Copy this code to your project source, e.g., to main.c  */
<#elseif isCallback == true>
/* Use Case 3 - Callback implementation. Copy this code to your project source, e.g., to main.c  */
</#if>
<#if isTestMode == false>
/* ------------------------------------------------------------------
</#if>
<#if isTestMode == true>
#include "../../system/system.h"
#include "uc3.h"
<#else>
#include "mcc_generated_files/system/system.h"
</#if>
#include <string.h>

#define MAX_COMMAND_LEN         (8U)
#define LINEFEED_CHAR           ((uint8_t)'\n')
#define CARRIAGERETURN_CHAR     ((uint8_t)'\r')

static uint8_t command[MAX_COMMAND_LEN];
static uint8_t index = 0;
static uint8_t readMessage;

void UART_ExecuteCommand(char *command);
void UART_ProcessCommand(void);

<#if isErrorHandling == true>
void UART_FramingErrorCallback(void);
void UART_OverrunErrorCallback(void);
<#if isAVR == true>
void UART_ParityErrorCallback(void);
</#if>

void UART_FramingErrorCallback(void)
{
    (void)printf("UART Framing Error Occurred.\r\n");
}

void UART_OverrunErrorCallback(void)
{
    (void)printf("UART Buffer Overrun Error Occurred.\r\n");
}

<#if isAVR == true>
void UART_ParityErrorCallback(void)
{
    (void)printf("UART Parity Error Occurred.\r\n");
}
</#if>
</#if>

void UART_ExecuteCommand(char *command)
{
    if(strcmp(command, "ON") == 0)
    {
        IO_LED_SetLow();
        (void)printf("OK, LED ON.\r\n");
    }
    else if (strcmp(command, "OFF") == 0)
    {
        IO_LED_SetHigh();
        (void)printf("OK, LED OFF.\r\n");
    }
    else
    {
        (void)printf("Incorrect command.\r\n");
    }
}

void UART_ProcessCommand(void)
{
    <#if isPolled == true>
    if(UART.IsRxReady())
    {
        <#if isErrorHandling == true>
        UART.ErrorGet();
        </#if>
        readMessage = UART.Read();
        if ( (readMessage != LINEFEED_CHAR) && (readMessage != CARRIAGERETURN_CHAR) ) 
        {
            command[index++] = readMessage;
            if (index > MAX_COMMAND_LEN) 
            {
                (index) = 0;
            }
        }
    
           if (readMessage == CARRIAGERETURN_CHAR) 
           {
                command[index] = '\0';
                index = 0;
                UART_ExecuteCommand(command);
            }
    }
    <#else>
    readMessage = UART.Read();
    if ( (readMessage != LINEFEED_CHAR) && (readMessage != CARRIAGERETURN_CHAR) )
    {
        command[index++] = readMessage;
        if(index > MAX_COMMAND_LEN)
        {
            (index) = 0;
        }
    }
        
    if (readMessage == CARRIAGERETURN_CHAR)
    {
        command[index] = '\0';
        index = 0;
        UART_ExecuteCommand(command);
    }  
    </#if>
}

<#if isPolled == true>
<#if isTestMode == true>
void UART_Example3(void)
<#else>
int main(void)
</#if>
{
    SYSTEM_Initialize();
    <#if isErrorHandling == true>
    UART.FramingErrorCallbackRegister(&UART_FramingErrorCallback);
    UART.OverrunErrorCallbackRegister(&UART_OverrunErrorCallback);
    <#if isAVR == true>
    UART.ParityErrorCallbackRegister(&UART_ParityErrorCallback);
    </#if>
    </#if>
    
    (void)printf("In the terminal, send 'ON' to turn the LED on, and 'OFF' to turn it off.\r\n");
    (void)printf("Note: commands 'ON' and 'OFF' are case sensitive.\r\n");
    
    while(1)
    {
        UART_ProcessCommand();
    }
}
<#elseif isCallback == true>
<#if isTestMode == true>
void UART_Example3(void)
<#else>
int main(void)
</#if>
{
    SYSTEM_Initialize();
    
    UART.RxCompleteCallbackRegister(&UART_ProcessCommand);
    <#if isErrorHandling == true>
    UART.FramingErrorCallbackRegister(&UART_FramingErrorCallback);
    UART.OverrunErrorCallbackRegister(&UART_OverrunErrorCallback);
    <#if isAVR == true>
    UART.ParityErrorCallbackRegister(&UART_ParityErrorCallback);
    </#if>
    </#if>
    
    (void)printf("In the terminal, send 'ON' to turn the LED on, and 'OFF' to turn it off.\r\n");
    (void)printf("Note: commands 'ON' and 'OFF' are case sensitive.\r\n");
    <#if isAVR == false>
    INTERRUPT_GlobalInterruptEnable();
    <#if isPIC16 == true>
    INTERRUPT_PeripheralInterruptEnable();
    </#if>
    </#if>
    while(1) 
    { 
        ;
    }
}
</#if>
<#if isTestMode == false>
------------------------------------------------------------------ */
</#if>
/**
 End of File
*/